==> haskell-text-printer-0.5.0.2-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-GMdA7imLPQ1LOhpajbkfPL
key:                  text-printer-0.5.0.2-GMdA7imLPQ1LOhpajbkfPL
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  f94896d012274659122c567512be779d
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-GMdA7imLPQ1LOhpajbkfPL
depends:
    base-4.16.4.0 bytestring-0.11.4.0 pretty-1.1.3.6 text-1.2.5.0
    text-latin1-0.3.1-Kddmst24hhU3cJBvim6KrG

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5.0.2-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-HcwcmVv8Pm74K1Iqxk9hMH
key:                  text-printer-0.5.0.2-HcwcmVv8Pm74K1Iqxk9hMH
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  bd7b66dc7c9e05b573875e2234338624
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-HcwcmVv8Pm74K1Iqxk9hMH
depends:
    base-4.16.4.0 bytestring-0.11.4.0 pretty-1.1.3.6 text-1.2.5.0
    text-latin1-0.3.1-8QzhrQj50rH24KEI2b93h3

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
